# This file was generated by the Julia OpenAPI Code Generator
# Do not modify this file directly. Modify the OpenAPI specification instead.


@doc raw"""io.k8s.api.core.v1.PodStatus
PodStatus represents information about the status of a pod. Status may trail the actual state of a system, especially if the node that hosts the pod cannot contact the control plane.

    IoK8sApiCoreV1PodStatus(;
        conditions=nothing,
        containerStatuses=nothing,
        ephemeralContainerStatuses=nothing,
        hostIP=nothing,
        initContainerStatuses=nothing,
        message=nothing,
        nominatedNodeName=nothing,
        phase=nothing,
        podIP=nothing,
        podIPs=nothing,
        qosClass=nothing,
        reason=nothing,
        startTime=nothing,
    )

    - conditions::Vector{IoK8sApiCoreV1PodCondition} : Current service state of pod. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions
    - containerStatuses::Vector{IoK8sApiCoreV1ContainerStatus} : The list has one entry per container in the manifest. Each entry is currently the output of &#x60;docker inspect&#x60;. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status
    - ephemeralContainerStatuses::Vector{IoK8sApiCoreV1ContainerStatus} : Status for any ephemeral containers that have run in this pod. This field is alpha-level and is only populated by servers that enable the EphemeralContainers feature.
    - hostIP::String : IP address of the host to which the pod is assigned. Empty if not yet scheduled.
    - initContainerStatuses::Vector{IoK8sApiCoreV1ContainerStatus} : The list has one entry per init container in the manifest. The most recent successful init container will have ready &#x3D; true, the most recently started container will have startTime set. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status
    - message::String : A human readable message indicating details about why the pod is in this condition.
    - nominatedNodeName::String : nominatedNodeName is set only when this pod preempts other pods on the node, but it cannot be scheduled right away as preemption victims receive their graceful termination periods. This field does not guarantee that the pod will be scheduled on this node. Scheduler may decide to place the pod elsewhere if other nodes become available sooner. Scheduler may also decide to give the resources on this node to a higher priority pod that is created after preemption. As a result, this field may be different than PodSpec.nodeName when the pod is scheduled.
    - phase::String : The phase of a Pod is a simple, high-level summary of where the Pod is in its lifecycle. The conditions array, the reason and message fields, and the individual container status arrays contain more detail about the pod&#39;s status. There are five possible phase values:  Pending: The pod has been accepted by the Kubernetes system, but one or more of the container images has not been created. This includes time before being scheduled as well as time spent downloading images over the network, which could take a while. Running: The pod has been bound to a node, and all of the containers have been created. At least one container is still running, or is in the process of starting or restarting. Succeeded: All containers in the pod have terminated in success, and will not be restarted. Failed: All containers in the pod have terminated, and at least one container has terminated in failure. The container either exited with non-zero status or was terminated by the system. Unknown: For some reason the state of the pod could not be obtained, typically due to an error in communicating with the host of the pod.  More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-phase
    - podIP::String : IP address allocated to the pod. Routable at least within the cluster. Empty if not yet allocated.
    - podIPs::Vector{IoK8sApiCoreV1PodIP} : podIPs holds the IP addresses allocated to the pod. If this field is specified, the 0th entry must match the podIP field. Pods may be allocated at most 1 value for each of IPv4 and IPv6. This list is empty if no IPs have been allocated yet.
    - qosClass::String : The Quality of Service (QOS) classification assigned to the pod based on resource requirements See PodQOSClass type for available QOS classes More info: https://git.k8s.io/community/contributors/design-proposals/node/resource-qos.md
    - reason::String : A brief CamelCase message indicating details about why the pod is in this state. e.g. &#39;Evicted&#39;
    - startTime::ZonedDateTime : Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON.  Wrappers are provided for many of the factory methods that the time package offers.
"""
Base.@kwdef mutable struct IoK8sApiCoreV1PodStatus <: OpenAPI.APIModel
    conditions::Union{Nothing, Vector} = nothing # spec type: Union{ Nothing, Vector{IoK8sApiCoreV1PodCondition} }
    containerStatuses::Union{Nothing, Vector} = nothing # spec type: Union{ Nothing, Vector{IoK8sApiCoreV1ContainerStatus} }
    ephemeralContainerStatuses::Union{Nothing, Vector} = nothing # spec type: Union{ Nothing, Vector{IoK8sApiCoreV1ContainerStatus} }
    hostIP::Union{Nothing, String} = nothing
    initContainerStatuses::Union{Nothing, Vector} = nothing # spec type: Union{ Nothing, Vector{IoK8sApiCoreV1ContainerStatus} }
    message::Union{Nothing, String} = nothing
    nominatedNodeName::Union{Nothing, String} = nothing
    phase::Union{Nothing, String} = nothing
    podIP::Union{Nothing, String} = nothing
    podIPs::Union{Nothing, Vector} = nothing # spec type: Union{ Nothing, Vector{IoK8sApiCoreV1PodIP} }
    qosClass::Union{Nothing, String} = nothing
    reason::Union{Nothing, String} = nothing
    startTime::Union{Nothing, ZonedDateTime} = nothing

    function IoK8sApiCoreV1PodStatus(conditions, containerStatuses, ephemeralContainerStatuses, hostIP, initContainerStatuses, message, nominatedNodeName, phase, podIP, podIPs, qosClass, reason, startTime, )
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("conditions"), conditions)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("containerStatuses"), containerStatuses)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("ephemeralContainerStatuses"), ephemeralContainerStatuses)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("hostIP"), hostIP)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("initContainerStatuses"), initContainerStatuses)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("message"), message)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("nominatedNodeName"), nominatedNodeName)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("phase"), phase)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("podIP"), podIP)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("podIPs"), podIPs)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("qosClass"), qosClass)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("reason"), reason)
        OpenAPI.validate_property(IoK8sApiCoreV1PodStatus, Symbol("startTime"), startTime)
        return new(conditions, containerStatuses, ephemeralContainerStatuses, hostIP, initContainerStatuses, message, nominatedNodeName, phase, podIP, podIPs, qosClass, reason, startTime, )
    end
end # type IoK8sApiCoreV1PodStatus

const _property_types_IoK8sApiCoreV1PodStatus = Dict{Symbol,String}(Symbol("conditions")=>"Vector{IoK8sApiCoreV1PodCondition}", Symbol("containerStatuses")=>"Vector{IoK8sApiCoreV1ContainerStatus}", Symbol("ephemeralContainerStatuses")=>"Vector{IoK8sApiCoreV1ContainerStatus}", Symbol("hostIP")=>"String", Symbol("initContainerStatuses")=>"Vector{IoK8sApiCoreV1ContainerStatus}", Symbol("message")=>"String", Symbol("nominatedNodeName")=>"String", Symbol("phase")=>"String", Symbol("podIP")=>"String", Symbol("podIPs")=>"Vector{IoK8sApiCoreV1PodIP}", Symbol("qosClass")=>"String", Symbol("reason")=>"String", Symbol("startTime")=>"ZonedDateTime", )
OpenAPI.property_type(::Type{ IoK8sApiCoreV1PodStatus }, name::Symbol) = Union{Nothing,eval(Base.Meta.parse(_property_types_IoK8sApiCoreV1PodStatus[name]))}

function check_required(o::IoK8sApiCoreV1PodStatus)
    true
end

function OpenAPI.validate_property(::Type{ IoK8sApiCoreV1PodStatus }, name::Symbol, val)
    if name === Symbol("startTime")
        OpenAPI.validate_param(name, "IoK8sApiCoreV1PodStatus", :format, val, "date-time")
    end
end
